@@ -1,5 +1,5 @@
 /*********************************************************************
- *   Copyright 2010, UCAR/Unidata
+ *   Copyright 2018, UCAR/Unidata
  *   See netcdf/COPYRIGHT file for copying and redistribution conditions.
  *   $Header$
  *********************************************************************/
@@ -7,6 +7,7 @@
 #ifndef NCLOG_H
 #define NCLOG_H
 
+#include <stdarg.h>
 #include "ncexternl.h"
 
 #define NCENVFLAG "NCLOGFILE"
@@ -28,12 +29,10 @@ EXTERNL void nclogclose(void);
 
 /* The tag value is an arbitrary integer */
 EXTERNL void nclog(int tag, const char* fmt, ...);
+EXTERNL void ncvlog(int tag, const char* fmt, va_list ap);
 EXTERNL void nclogtext(int tag, const char* text);
 EXTERNL void nclogtextn(int tag, const char* text, size_t count);
 
-/* Provide printable names for tags */
-EXTERNL void nclogsettags(char** tagset, char* dfalt);
-
 #if defined(_CPLUSPLUS_) || defined(__CPLUSPLUS__)
 }
 #endif
