@@ -1,5 +1,5 @@
 /*
- *	Copyright 1996, University Corporation for Atmospheric Research
+ *	Copyright 2018, University Corporation for Atmospheric Research
  *	See netcdf/COPYRIGHT file for copying and redistribution conditions.
  */
 /* $Id: posixio.c,v 1.89 2010/05/22 21:59:08 dmh Exp $ */
@@ -41,10 +41,6 @@
 #define NC_NOERR 0
 #endif
 
-#ifndef HAVE_SSIZE_T
-typedef int ssize_t;
-#endif
-
 #ifndef SEEK_SET
 #define SEEK_SET 0
 #define SEEK_CUR 1
@@ -188,7 +184,11 @@ blksize(int fd)
 		return 8192;
 	}
 	/* else, silent in the face of error */
+#else
+	NC_UNUSED(fd);
 #endif
+#else
+	NC_UNUSED(fd);
 #endif
 	return (size_t) 2 * pagesize();
 }
@@ -449,6 +449,7 @@ px_rel(ncio_px *const pxp, off_t offset, int rflags)
 		 && offset < pxp->bf_offset + (off_t) pxp->bf_extent);
 	assert(pIf(fIsSet(rflags, RGN_MODIFIED),
 		fIsSet(pxp->bf_rflags, RGN_WRITE)));
+	NC_UNUSED(offset);
 
 	if(fIsSet(rflags, RGN_MODIFIED))
 	{
@@ -467,7 +468,7 @@ px_rel(ncio_px *const pxp, off_t offset, int rflags)
    RGN_MODIFIED.
 
    For POSIX system, without NC_SHARE, this becomes the rel function
-   pointed to by the ncio rel function pointer. It mearly checks for
+   pointed to by the ncio rel function pointer. It merely checks for
    file write permission, then calls px_rel to do everything.
 
    nciop - pointer to ncio struct.
@@ -514,7 +515,7 @@ ncio_px_rel(ncio *const nciop, off_t offset, int rflags)
    * The blkextent can't be more than twice the pxp->blksz. That's
    because the pxp->blksize is the sizehint, and in ncio_px_init2 the
    buffer (pointed to by pxp->bf-base) is allocated with 2 *
-   *sizehintp. This is checked (unneccesarily) more than once in
+   *sizehintp. This is checked (unnecessarily) more than once in
    asserts.
 
    * If this is called on a newly opened file, pxp->bf_offset will be
@@ -740,11 +741,7 @@ done:
 	pxp->bf_rflags |= rflags;
 	pxp->bf_refcount++;
 
-#ifndef __CHAR_UNSIGNED__
-    *vpp = (void *)((char *)pxp->bf_base + diff);
-#else
     *vpp = (void *)((signed char*)pxp->bf_base + diff);
-#endif
 	return NC_NOERR;
 }
 
@@ -805,6 +802,7 @@ px_double_buffer(ncio *const nciop, off_t to, off_t from,
 	int status = NC_NOERR;
 	void *src;
 	void *dest;
+	NC_UNUSED(rflags);
 
 #if INSTRUMENT
 fprintf(stderr, "\tdouble_buffr %ld %ld %ld\n",
@@ -1134,7 +1132,7 @@ typedef struct ncio_spx {
 /* This function releases the region specified by offset.
 
    For POSIX system, with NC_SHARE, this becomes the rel function
-   pointed to by the ncio rel function pointer. It mearly checks for
+   pointed to by the ncio rel function pointer. It merely checks for
    file write permission, then calls px_rel to do everything.
 
    nciop - pointer to ncio struct.
@@ -1160,6 +1158,7 @@ ncio_spx_rel(ncio *const nciop, off_t offset, int rflags)
 	assert(offset < pxp->bf_offset + X_ALIGN);
 	assert(pxp->bf_cnt % X_ALIGN == 0 );
 #endif
+	NC_UNUSED(offset);
 
 	if(fIsSet(rflags, RGN_MODIFIED))
 	{
@@ -1408,6 +1407,7 @@ ncio_spx_move(ncio *const nciop, off_t to, off_t from,
 static int
 ncio_spx_sync(ncio *const nciop)
 {
+	NC_UNUSED(nciop);
 	/* NOOP */
 	return NC_NOERR;
 }
@@ -1462,7 +1462,7 @@ ncio_spx_init2(ncio *const nciop, const size_t *const sizehintp)
 
 
 /* First half of init for ncio_spx struct, setting the rel, get, move,
-   snyc, and free function pointers to the NC_SHARE versions of these
+   sync, and free function pointers to the NC_SHARE versions of these
    functions (i.e. the ncio_spx_* functions).
 */
 static void
@@ -1600,6 +1600,7 @@ posixio_create(const char *path, int ioflags,
 	int oflags = (O_RDWR|O_CREAT);
 	int fd;
 	int status;
+	NC_UNUSED(parameters);
 
 	if(initialsz < (size_t)igeto + igetsz)
 		initialsz = (size_t)igeto + igetsz;
@@ -1730,7 +1731,7 @@ unwind_new:
    nciopp - pointer to pointer that will get address of newly created
    and inited ncio struct.
 
-   igetvpp - handle to pass back pointer to data from inital page
+   igetvpp - handle to pass back pointer to data from initial page
    read, if this were ever used, which it isn't.
 */
 int
@@ -1744,6 +1745,7 @@ posixio_open(const char *path,
 	int oflags = fIsSet(ioflags, NC_WRITE) ? O_RDWR : O_RDONLY;
 	int fd = -1;
 	int status = 0;
+	NC_UNUSED(parameters);
 
 	if(path == NULL || *path == 0)
 		return EINVAL;
