@@ -1,5 +1,5 @@
 /*********************************************************************
- *   Copyright 2009, UCAR/Unidata
+ *   Copyright 2018, UCAR/Unidata
  *   See netcdf/COPYRIGHT file for copying and redistribution conditions.
  *********************************************************************/
 
@@ -9,6 +9,9 @@
 #ifdef ENABLE_C
 
 #include <math.h> 
+#ifndef isnan
+extern int isnan(double);
+#endif
 
 static int c_uid = 0;
 
