@@ -1,4 +1,4 @@
-/* Copyright 2009, UCAR/Unidata and OPeNDAP, Inc.
+/* Copyright 2018, UCAR/Unidata and OPeNDAP, Inc.
    See the COPYRIGHT file for more information. */
 
 #include "config.h"
@@ -12,27 +12,16 @@
 /* Mnemonic */
 #define OPTARG void*
 
+/* Define some .rc file entries of interest*/
 #define NETRCFILETAG "HTTP.NETRC"
 
+/* Check return value */
 #define CHECK(state,flag,value) {if(check(state,flag,(void*)value) != OC_NOERR) {goto done;}}
 
 static OCerror
 check(OCstate* state, int flag, void* value)
 {
     OCerror stat = ocset_curlopt(state,flag,value);
-#ifdef OCDEBUG
-    long l = (long)value;
-    const char* name = occurlflagbyflag(flag)->name;
-    if(l <= 1000) {
-	OCDBG2("%s=%ld",name,l);
-    } else {
-	char show[65];
-	char* s = (char*)value;
-	strncpy(show,s,sizeof(show)-1);
-	show[sizeof(show)-1] = '\0';
-	OCDBG2("%s=%s",name,show);
-    }
-#endif
     return stat;
 }
 
@@ -93,6 +82,11 @@ ocset_curlflag(OCstate* state, int flag)
 	    CHECK(state, CURLOPT_TIMEOUT, (OPTARG)((long)state->auth.curlflags.timeout));
 	break;
 
+    case CURLOPT_CONNECTTIMEOUT:
+	if(state->auth.curlflags.connecttimeout)
+	    CHECK(state, CURLOPT_CONNECTTIMEOUT, (OPTARG)((long)state->auth.curlflags.connecttimeout));
+	break;
+
     case CURLOPT_USERAGENT:
         if(state->auth.curlflags.useragent)
 	    CHECK(state, CURLOPT_USERAGENT, state->auth.curlflags.useragent);
@@ -153,12 +147,26 @@ ocset_curlflag(OCstate* state, int flag)
     }
     break;
 
-    default: {
-	struct OCCURLFLAG* f = occurlflagbyflag(flag);
-	if(f != NULL)
-	    nclog(NCLOGWARN,"Attempt to update unexpected curl flag: %s",
-				f->name);
-	} break;
+#ifdef HAVE_CURLOPT_BUFFERSIZE
+    case CURLOPT_BUFFERSIZE:
+	CHECK(state, CURLOPT_BUFFERSIZE, (OPTARG)state->curlbuffersize);
+	break;
+#endif
+
+#ifdef HAVE_CURLOPT_KEEPALIVE
+    case CURLOPT_TCP_KEEPALIVE:
+	if(state->curlkeepalive.active != 0)
+	    CHECK(state, CURLOPT_TCP_KEEPALIVE, (OPTARG)1L);
+	if(state->curlkeepalive.idle > 0)
+	    CHECK(state, CURLOPT_TCP_KEEPIDLE, (OPTARG)state->curlkeepalive.idle);
+	if(state->curlkeepalive.interval > 0)
+	    CHECK(state, CURLOPT_TCP_KEEPINTVL, (OPTARG)state->curlkeepalive.interval);
+	break;
+#endif
+
+    default:
+        nclog(NCLOGWARN,"Attempt to update unexpected curl flag: %d",flag);
+	break;
     }
 done:
     return stat;
@@ -186,6 +194,7 @@ ocset_flags_perlink(OCstate* state)
     if(stat == OC_NOERR) stat = ocset_curlflag(state,CURLOPT_NETRC);
     if(stat == OC_NOERR) stat = ocset_curlflag(state,CURLOPT_VERBOSE);
     if(stat == OC_NOERR) stat = ocset_curlflag(state,CURLOPT_TIMEOUT);
+    if(stat == OC_NOERR) stat = ocset_curlflag(state,CURLOPT_CONNECTTIMEOUT);
     if(stat == OC_NOERR) stat = ocset_curlflag(state,CURLOPT_USERAGENT);
     if(stat == OC_NOERR) stat = ocset_curlflag(state,CURLOPT_COOKIEJAR);
     if(stat == OC_NOERR) stat = ocset_curlflag(state,CURLOPT_USERPWD);
@@ -194,6 +203,16 @@ ocset_flags_perlink(OCstate* state)
     if(stat == OC_NOERR) stat = ocset_curlflag(state, CURLOPT_FOLLOWLOCATION);
     if(stat == OC_NOERR) stat = ocset_curlflag(state, CURLOPT_MAXREDIRS);
     if(stat == OC_NOERR) stat = ocset_curlflag(state, CURLOPT_ERRORBUFFER);
+
+#ifdef HAVE_CURLOPT_BUFFERSIZE
+    /* Optional */
+    if(stat == OC_NOERR && state->curlbuffersize > 0)
+	stat = ocset_curlflag(state, CURLOPT_BUFFERSIZE);
+#endif
+#ifdef HAVE_CURLOPT_KEEPALIVE
+    if(stat == NC_NOERR && state->curlkeepalive.active != 0)
+        stat = ocset_curlflag(state, CURLOPT_TCP_KEEPALIVE);
+#endif
     return stat;
 }
 
@@ -232,5 +251,3 @@ oc_curl_protocols(OCstate* state)
 	    state->auth.curlflags.proto_https=1;
     }
 }
-
-
