@@ -1,4 +1,4 @@
-/* Copyright 2009, UCAR/Unidata and OPeNDAP, Inc.
+/* Copyright 2018, UCAR/Unidata and OPeNDAP, Inc.
    See the COPYRIGHT file for more information. */
 
 #include "config.h"
@@ -13,7 +13,7 @@
 #include <fcntl.h>
 #endif
 
-#if defined(_WIN32) || defined(_WIN64)
+#ifdef _MSC_VER
 #include <io.h>
 #define mode_t int
 #endif
@@ -22,7 +22,7 @@
 #include "ocdebug.h"
 
 /* Order is important: longest first */
-static char* DDSdatamarks[3] = {"Data:\r\n","Data:\n",(char*)NULL};
+static const char* DDSdatamarks[3] = {"Data:\r\n","Data:\n",(char*)NULL};
 
 /* Not all systems have strndup, so provide one*/
 char*
@@ -38,7 +38,7 @@ ocstrndup(const char* s, size_t len)
 }
 
 /* Do not trust strncmp semantics; this one
-   compares upto len chars or to null terminators */
+   compares up to len chars or to null terminators */
 int
 ocstrncmp(const char* s1, const char* s2, size_t len)
 {
@@ -136,12 +136,12 @@ ocfindbod(NCbytes* buffer, size_t* bodp, size_t* ddslenp)
     unsigned int i;
     char* content;
     size_t len = ncbyteslength(buffer);
-    char** marks;
+    const char** marks;
     
     content = ncbytescontents(buffer);
 
     for(marks = DDSdatamarks;*marks;marks++) {
-	char* mark = *marks;
+	const char* mark = *marks;
         size_t tlen = strlen(mark);
         for(i=0;i<len;i++) {
 	    if((i+tlen) <= len 
@@ -471,7 +471,7 @@ done:
    for set of dimension indices.
 */
 size_t
-ocarrayoffset(size_t rank, size_t* sizes, size_t* indices)
+ocarrayoffset(size_t rank, size_t* sizes, const size_t* indices)
 {
     unsigned int i;
     size_t count = 0;
@@ -538,7 +538,7 @@ oc_ispacked(OCnode* node)
 /* Must be consistent with ocx.h.OCDT */
 #define NMODES 6
 #define MAXMODENAME 8 /*max (strlen(modestrings[i])) */
-static char* modestrings[NMODES+1] = {
+static const char* modestrings[NMODES+1] = {
 "FIELD", /* ((OCDT)(1<<0)) field of a container */
 "ELEMENT", /* ((OCDT)(1<<1)) element of a structure array */
 "RECORD", /* ((OCDT)(1<<2)) record of a sequence */
@@ -548,19 +548,23 @@ static char* modestrings[NMODES+1] = {
 NULL,
 };
 
-const char*
+char*
 ocdtmodestring(OCDT mode,int compact)
 {
-    static char result[1+(NMODES*(MAXMODENAME+1))]; /* hack to avoid malloc */
+    char* result = NULL;
     int i;
-    char* p = result;
+    char* p = NULL;
+
+    result = malloc(1+(NMODES*(MAXMODENAME+1)));
+    if(result == NULL) return NULL;
+    p = result;
     result[0] = '\0';
     if(mode == 0) {
 	if(compact) *p++ = '-';
 	else if(!occoncat(result,sizeof(result),1,"NONE"))
 	    return NULL;
     } else for(i=0;;i++) {
-	char* ms = modestrings[i];
+	const char* ms = modestrings[i];
 	if(ms == NULL) break;
 	if(!compact && i > 0)
 	    if(!occoncat(result,sizeof(result),1,","))
@@ -685,56 +689,6 @@ done:
     return status;    
 }
 
-
-/**
-Wrap mktmp and return the generated name
-*/
-
-int
-ocmktmp(const char* base, char** tmpnamep)
-{
-    int fd;
-    char tmpname[OCPATHMAX+1];
-
-    if(!occopycat(tmpname,sizeof(tmpname)-1,1,base)) {
-	return OC_EOVERRUN;
-    }
-#ifdef HAVE_MKSTEMP
-    if(!occoncat(tmpname,sizeof(tmpname)-1,1,"XXXXXX")) {
-	return OC_EOVERRUN;
-    }
-    /* Note Potential problem: old versions of this function
-       leave the file in mode 0666 instead of 0600 */
-    {
-	mode_t mask=umask(0077);
-	fd = mkstemp(tmpname);
-	(void)umask(mask);
-    }
-#else /* !HAVE_MKSTEMP */
-    /* Need to simulate by using some kind of pseudo-random number */
-    {
-	int rno = rand();
-	char spid[7];
-	if(rno < 0) rno = -rno;
-        snprintf(spid,sizeof(spid),"%06d",rno);
-	if(!occoncat(tmpname,sizeof(tmpname)-1,1,spid)) {
-	    return OC_EOVERRUN;
-        }
-#if defined(_WIN32) || defined(_WIN64)
-        fd=NCopen3(tmpname,O_RDWR|O_BINARY|O_CREAT, _S_IREAD|_S_IWRITE);
-#  else
-        fd=NCopen3(tmpname,O_RDWR|O_CREAT|O_EXCL, S_IRWXU);
-#  endif
-    }
-#endif /* !HAVE_MKSTEMP */
-    if(fd < 0) {
-       return OC_EOPEN;
-    } else
-	close(fd);
-    if(tmpnamep) *tmpnamep = strdup(tmpname);
-    return OC_NOERR;
-}
-
 /* merge two envv style lists */
 char**
 ocmerge(const char** list1, const char** list2)
